@@ -4,7 +4,7 @@ __version__ = '0.2.2'
 
 import argparse
 
-from start import start_code
+from .start import start_code
 
 
 def get_version():
